@@ -64,6 +64,32 @@ class BillingTypeAdmin(ModelAdmin):
     ordering = ['id']
 
 
+class BookAdmin(ModelAdmin):
+
+    fieldsets = (
+        (None, {
+            'fields': ('name',
+                       'author',
+                       'publisher',
+                       'edition',
+                       'language',
+                       'isbn',
+                       )}),
+        (_(u'Timestamp'), {
+            'classes': ('collapse',),
+            'fields': ('created',
+                       'created_by',
+                       'updated',
+                       'updated_by'
+                       )}),
+    )
+    list_display = ('id', 'name', 'author', 'publisher', 'isbn',
+                    'created', 'updated')
+    list_display_links = ('id',)
+    list_filter = ['publisher']
+    readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
+
+
 class BookingAdmin(ModelAdmin):
 
     date_hierarchy = 'created'
@@ -122,13 +148,88 @@ class BookingAdmin(ModelAdmin):
 
 class BookingHistoryAdmin(ModelAdmin):
 
-    list_display = ('id', 'action', 'created', 'updated')
-    list_display_links = ('id',)
-    list_filter = ['project',]
+    fieldsets = (
+        (None, {
+            'fields': ('title',
+                       'description',
+                       'location',
+                       )}),
+        (_(u'Ticket information'), {
+            'fields': ('issue',
+            )}),
+        (_(u'Details'), {
+            'fields': ('day',
+                       'project',
+                       'step',
+            )}),
+        (_(u'Time information'), {
+            'fields': ('from_time',
+                       'to_time',
+                       'duration',
+            )}),
+        (_(u'Billing information'), {
+            'classes': ('collapse',),
+            'fields': ('invoice_no',
+                       'coefficient',
+                       'external_coefficient',
+            )}),
+        (_(u'Timestamp'), {
+            'classes': ('collapse',),
+            'fields': ('created',
+                       'created_by',
+                       'updated',
+                       'updated_by'
+                       )}),
+    )
+    list_display = ('id', 'action', 'created_by', 'day', 'project', 'step',
+                    'get_title', 'get_duration', 'created',
+                    'updated')
+    list_display_links = ('id', 'get_title')
+    list_filter = ['project', 'created_by']
+    ordering = ['id']
+    raw_id_fields = ['issue', 'step']
+    readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
+
+    def get_duration(self, booking_history):
+        return format_minutes_to_time(booking_history.duration)
+    get_duration.admin_order_field = 'duration'
+    get_duration.short_description = _(u'Duration')
+
+    def get_title(self, booking_history):
+        return booking_history.get_title()
+    get_title.short_description = _(u'Activity')
+
+
+class BookUserAdmin(ModelAdmin):
+
+    fieldsets = (
+        (None, {
+            'fields': ('book',
+                       'user',
+                       'lent',
+                       'returned',
+                       )}),
+        (_(u'Timestamp'), {
+            'classes': ('collapse',),
+            'fields': ('created',
+                       'created_by',
+                       'updated',
+                       'updated_by'
+                       )}),
+    )
+    list_display = ('id', 'book', 'user', 'lent', 'returned')
+    list_display_links = ('id', 'book')
+    list_filter = ['user',]
     ordering = ['id']
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
 
 
+class CommissionStatusAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'description')
+    list_display_links = ('id', 'name')
+    ordering = ['id']
+
 
 class CompanyAdmin(ModelAdmin):
     """Admin class for model :class:`Company`"""
@@ -222,6 +323,13 @@ class ContactAdmin(ModelAdmin):
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
 
 
+class CountryAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'printable_name', 'num_code', 'iso2', 'iso3',
+                    'dial_code')
+    list_display_links = ('id', 'name' ,'printable_name')
+
+
 class CustomerAdmin(ModelAdmin):
     """Admin class for model :class:`Customer`"""
 
@@ -275,6 +383,76 @@ class DepartmentAdmin(ModelAdmin):
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
 
 
+class HardwareAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'manufacturer', 'group', 'model',
+                    'inventory_no', 'serial_no')
+    list_display_links = ('id', 'name')
+
+
+class HardwareGroupAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'description')
+    list_display_links = ('id', 'name')
+
+
+class HardwareUserAdmin(ModelAdmin):
+
+    list_display = ('id', 'hardware', 'user')
+    list_display_links = ('id', )
+
+
+class LanguageAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'cid',)
+    list_display_links = ('id', 'name')
+
+
+class ManufacturerAdmin(ModelAdmin):
+
+    fieldsets = (
+        (None, {
+            'fields': ('name',
+                       'address',
+                       'communication',
+                       )}),
+        (_(u'Timestamp'), {
+            'classes': ('collapse',),
+            'fields': ('created',
+                       'created_by',
+                       'updated',
+                       'updated_by'
+                       )}),
+    )
+    list_display = ('id', 'name', 'created', 'updated')
+    list_display_links = ('id', 'name')
+    raw_id_fields = ['address', 'communication']
+    readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
+
+
+class NewsAdmin(ModelAdmin):
+
+    fieldsets = (
+        (None, {
+            'fields': ('title',
+                       'message',
+                       'valid_from',
+                       'valid_to',
+                       )}),
+        (_(u'Timestamp'), {
+            'classes': ('collapse',),
+            'fields': ('created',
+                       'created_by',
+                       'updated',
+                       'updated_by'
+                       )}),
+    )
+    list_display = ('id', 'title', 'valid_from', 'valid_to', 'created',
+                    'updated')
+    list_display_links = ('id', 'title')
+    readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
+
+
 class ProjectForm(forms.ModelForm):
 
     class Meta:
@@ -344,6 +522,13 @@ class ProjectAdmin(ModelAdmin):
             obj.save(user=request.user)
 
 
+class ProjectStatusAdmin(ModelAdmin):
+
+    list_display = ('id', 'name', 'description')
+    list_display_links = ('id', 'name')
+    ordering = ['id']
+
+
 class ProjectStepAdmin(ModelAdmin):
 
     fieldsets = (
@@ -567,19 +752,39 @@ class UserProfileAdmin(ModelAdmin):
 admin.site.register(models.Address, AddressAdmin)
 admin.site.register(models.AddressGroup, AddressGroupAdmin)
 admin.site.register(models.BillingType, BillingTypeAdmin)
+admin.site.register(models.Book, BookAdmin)
 admin.site.register(models.Booking, BookingAdmin)
 admin.site.register(models.BookingHistory, BookingHistoryAdmin)
+admin.site.register(models.BookUser, BookUserAdmin)
 admin.site.register(models.Communication, CommunicationAdmin)
+admin.site.register(models.CommissionStatus, CommissionStatusAdmin)
 admin.site.register(models.Company, CompanyAdmin)
 admin.site.register(models.Contact, ContactAdmin)
+admin.site.register(models.Country, CountryAdmin)
 admin.site.register(models.Customer, CustomerAdmin)
+# Day
+# DefaultProject
 admin.site.register(models.Department, DepartmentAdmin)
+# DepartmentUser
+admin.site.register(models.Hardware, HardwareAdmin)
+admin.site.register(models.HardwareGroup, HardwareGroupAdmin)
+admin.site.register(models.HardwareUser, HardwareUserAdmin)
+admin.site.register(models.Language, LanguageAdmin)
+admin.site.register(models.Manufacturer, ManufacturerAdmin)
+admin.site.register(models.News, NewsAdmin)
+# NewsGroup
 admin.site.register(models.Project, ProjectAdmin)
+# ProjectRate
+admin.site.register(models.ProjectStatus, ProjectStatusAdmin)
 admin.site.register(models.ProjectStep, ProjectStepAdmin)
 admin.site.register(models.ProjectStepStatus, ProjectStepStatusAdmin)
 admin.site.register(models.ProjectStepTemplate, ProjectStepTemplateAdmin)
 admin.site.register(models.ProjectTracker, ProjectTrackerAdmin)
 admin.site.register(models.ProjectType, ProjectTypeAdmin)
 admin.site.register(models.ProjectUser, ProjectUserAdmin)
+# ProjectUserRate
+# Salutation
+# Software
+# SoftwareGroup
 admin.site.register(models.Timer, TimerAdmin)
 admin.site.register(models.UserProfile, UserProfileAdmin)
