@@ -99,6 +99,7 @@ class Model(models.Model):
 
 
 class Account(User):
+    """Extension to Django`s :class:`User` object"""
 
     current_user_account = None
     starred_bookings = []
@@ -109,9 +110,17 @@ class Account(User):
 
     @classmethod
     def get_account_for_user(cls, user):
-        assert user.email
-        query = Account.objects.filter(email=user.email)
-        account = tuple(query)[0] or None
+        """Return a :class:`Account` instance by request.user
+
+        :param user: A :class:`User` instance
+        :returns: :class:`Account`
+        """
+        if user.email:
+            query = Account.objects.filter(email=user.email)
+            account = tuple(query)[0] or None
+        else:
+            query = Account.objects.filter(username=user.username)
+            account = tuple(query)[0] or None
         if account is not None:
             return account
 
@@ -328,6 +337,7 @@ class BillingType(Model):
 
     class Meta:
         db_table = u'k_abrechnungsart'
+        ordering = ('name',)
         verbose_name = _(u'Billing type')
         verbose_name_plural = _(u'Billing types')
 
@@ -367,6 +377,9 @@ class Book(Model):
         verbose_name = _(u'Book')
         verbose_name_plural = _(u'Books')
 
+    def __unicode__(self):
+        return self.name
+
 
 class BookUser(Model):
 
@@ -491,6 +504,14 @@ class Booking(Model):
             and self.id in account.starred_bookings
         return self._is_starred
 
+    def get_closing_reason(self):
+        if not self.is_closed():
+            return None
+        if self.day.locked:
+            return _(u'The day is locked.')
+        if self.project.is_closed():
+            return _(u'The project is closed or inactive.')
+
     def get_description(self):
         """Returns either the issue description or the issue description.
 
@@ -537,6 +558,10 @@ class Booking(Model):
         return hist
 
     def is_closed(self):
+        """Is the booking editable?
+
+        :returns: ``True`` or ``False``
+        """
         if self.project.is_closed() or self.day.locked:
             return True
         return False
@@ -545,7 +570,7 @@ class Booking(Model):
         """Set the next available position, depending on the day."""
         bookings = Booking.objects.filter(day=self.day)
         self.position = bookings.aggregate(models.Max('position'))[
-            'position__max'] + 1 or 0
+            'position__max'] or 0 + 1
 
     def revert(self, history):
         """Copy values from a history instance.
@@ -609,6 +634,8 @@ class BookingHistory(Model):
                                      verbose_name=_(u'Booking id'))
     title = models.CharField(db_column='hst_titel', max_length=255,
                              verbose_name=_(u'Title'))
+    description = models.TextField(db_column='hst_bem',
+                                   verbose_name=_(u'Description'))
     day = models.ForeignKey('Day', db_column='hst_taid',
                             verbose_name=_(u'Day'))
     position = models.IntegerField(db_column='hst_pos',
@@ -692,6 +719,24 @@ class BookingHistory(Model):
         """
         return HISTORY_ACTIONS[self.action]
 
+    def get_description(self):
+        """Returns either the issue description or the issue description.
+
+        :returns: Description as string
+        """
+        if self.issue:
+            retval = self.issue.description
+        else:
+            retval = self.description
+        return retval or _(u'No description')
+
+    def get_title(self):
+        if self.issue:
+            retval = u'#%d %s' % (self.issue.no, self.issue.title)
+        else:
+            retval = self.title
+        return retval or _(u'No title')
+
 
 #class BookingStatus(Model):
 
@@ -722,9 +767,13 @@ class CommissionStatus(Model):
 
     class Meta:
         db_table = u'k_beauftragungsstatus'
+        ordering = ('name',)
         verbose_name = _(u'Commission status')
         verbose_name_plural = _(u'Commission status')
 
+    def __unicode__(self):
+        return self.name
+
 
 class Communication(Model):
 
@@ -1080,6 +1129,9 @@ class HardwareGroup(Model):
         verbose_name = _(u'Hardware group')
         verbose_name_plural = _(u'Hardware groups')
 
+    def __unicode__(self):
+        return self.name
+
 
 class HardwareUser(Model):
 
@@ -1142,6 +1194,9 @@ class Manufacturer(Model):
         verbose_name = _(u'Manufacturer')
         verbose_name_plural = _(u'Manufacturers')
 
+    def __unicode__(self):
+        return self.name
+
 
 class News(Model):
 
@@ -1149,7 +1204,8 @@ class News(Model):
     title = models.CharField(max_length=200, db_column='neu_titel')
     message = models.TextField(db_column='neu_text')
     valid_from = models.DateField(db_column='neu_gueltig_ab', null=True)
-    valid_to = models.DateField(db_column='neu_gueltig_bis', null=True)
+    valid_to = models.DateField(db_column='neu_gueltig_bis', null=True,
+                                blank=True)
     created_by = models.ForeignKey(User, db_column='neu_crid',
                                    null=True, related_name='news_creators',
                                    verbose_name=_(u'Created by'))
@@ -1271,6 +1327,15 @@ class Project(Model):
         return self.status.id in (PROJECT_STATUS_CLOSED,
                                   PROJECT_STATUS_DELETED,
                                   PROJECT_STATUS_IDLE)
+    def get_description(self):
+        """Return the description or an alternate string.
+
+        :returns: Description or default string
+        """
+        if self.description:
+            return self.description
+        else:
+            return _(u'No description')
 
     def get_project_steps(self, active_only=True):
         query = ProjectStep.objects.filter(project=self)
@@ -1284,6 +1349,10 @@ class Project(Model):
         #query = query.order_by('')
         return query
 
+    def has_trackers(self):
+        query = ProjectTracker.objects.filter(project=self)
+        return query.count() > 0
+
 
 class ProjectRate(Model):
 
