@@ -25,6 +25,7 @@ from django.utils import formats
 
 from decorators import (
     booking_required,
+    booking_owner_required,
     booking_key_required,
     get_required,
     post_required,
@@ -213,8 +214,7 @@ def _edit_profile(request):
         return respond(request, 'profile.html', {'form': form})
 
 
-@login_required
-@booking_required
+@booking_owner_required
 @permission_required('inhouse.change_booking')
 def edit_booking(request):
     booking = request.booking
@@ -238,7 +238,8 @@ def edit_booking(request):
             'hours': hours,
             'minutes': minutes / 15,
             'title': booking.title,
-            'description': booking.description}
+            'description': booking.description,
+            'location': booking.location}
         if booking.issue:
             initial.update({
                 'tracker': booking.issue.tracker.id,
@@ -292,6 +293,7 @@ def _save_booking(request, booking_id=None):
         #booking.to_time = form.cleaned_data['to_time']
         booking.title = form.cleaned_data['title']
         booking.description = form.cleaned_data['description']
+        booking.location = form.cleaned_data['location']
         try:
             issue_no = int(form.cleaned_data.get('issue_no'))
         except:
@@ -501,9 +503,11 @@ def show_user(request, user_id):
 
     :param user_id: Id of the user to show
     """
-    query = User.objects.filter(id=user_id)
-    user = query[0]
-    return respond(request, 'user.html', {'user_to_show': user})
+    user = User.objects.filter(id=user_id)[0]
+    projects = models.Project.objects.get_by_user(
+        user, active_only=False).order_by('name')
+    return respond(request, 'user.html', {'user_to_show': user,
+                                          'projects': projects})
 
 
 @post_required
@@ -592,11 +596,6 @@ def edit_timer(request):
 
 @login_required
 def time(request):
-    return respond(request, 'time.html', {})
-
-
-@login_required
-def timeline(request):
     today = datetime.date.today()
     query = models.Booking.objects.select_related().filter(
         created_by=request.user).order_by('-created')
